# -*- coding: utf-8 -*-
#
# Copyright 2011-2016 Lancaster University.
#
#
# This file is part of Yarely.
#
# Licensed under the Apache License, Version 2.0.
# For full licensing information see /LICENSE.


""" Yarely module. """

__author__ = 'Lancaster University'
__copyright__ = "Copyright (C) 2011-2017 {author}".format(author=__author__)
__license__ = "Apache Software License 2.0"
__email__ = 'e-campus-help@lancaster.ac.uk'
__version__ = '0.1.0'
__shortdescription__ = (
    "Yarely is an open Digital Signage Platform developed by the eCampus team "
    "at Lancaster University."
)
